const resources = [
	{
		version: '17.0.0',
		main: '/usr/share/unicode/UnicodeData.txt',
		scripts: '/usr/share/unicode/Scripts.txt',
		'script-extensions':
			'/usr/share/unicode/ScriptExtensions.txt',
		blocks: '/usr/share/unicode/Blocks.txt',
		properties: '/usr/share/unicode/PropList.txt',
		'name-aliases': '/usr/share/unicode/NameAliases.txt',
		'derived-binary-properties':
			'/usr/share/unicode/extracted/DerivedBinaryProperties.txt',
		'derived-core-properties':
			'/usr/share/unicode/DerivedCoreProperties.txt',
		'derived-general-category':
			'/usr/share/unicode/extracted/DerivedGeneralCategory.txt',
		'derived-normalization-properties':
			'/usr/share/unicode/DerivedNormalizationProps.txt',
		'composition-exclusions':
			'/usr/share/unicode/CompositionExclusions.txt',
		'case-folding': '/usr/share/unicode/CaseFolding.txt',
		'special-casing': '/usr/share/unicode/SpecialCasing.txt',
		'bidi-mirroring': '/usr/share/unicode/BidiMirroring.txt',
		'bidi-brackets': '/usr/share/unicode/BidiBrackets.txt',
		'line-break': '/usr/share/unicode/LineBreak.txt',
		'word-break':
			'/usr/share/unicode/auxiliary/WordBreakProperty.txt',
		// Emoji, Emoji_Presentation, Emoji_Modifier, Emoji_Modifier_Base, Emoji_Component, Extended_Pictographic
		emoji: '/usr/share/unicode/emoji/emoji-data.txt',
		// Emoji_Keycap_Sequence, Emoji_Flag_Sequence, Emoji_Modifier_Sequence
		'emoji-sequences':
			'/usr/share/unicode/emoji/emoji-sequences.txt',
		// Emoji_ZWJ_Sequence
		'emoji-zwj-sequences':
			'/usr/share/unicode/emoji/emoji-zwj-sequences.txt',
		// Emoji_Test (not an official property)
		'emoji-test': '/usr/share/unicode/emoji/emoji-test.txt',
	}
];

module.exports = resources;


